==> jc-1.4.0.tar.gz: java/awt/datatransfer/UnsupportedFlavorException.h <==
// public class java.awt.datatransfer.UnsupportedFlavorException

// class file dependencies
// @dep_class 2f25e67d9a1f0e23 java_awt_datatransfer_UnsupportedFlavorException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_datatransfer_UnsupportedFlavorException_H_
#define _JC_java_awt_datatransfer_UnsupportedFlavorException_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs	_jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs	_jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$refs	_jc_java_awt_datatransfer_UnsupportedFlavorException$refs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs	_jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$object	_jc_java_awt_datatransfer_UnsupportedFlavorException$object;

typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct	_jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct;
typedef const struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods	_jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods;
typedef const struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtable	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtable;
typedef const struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtype	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtype;

// Class fields structure
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct _jc_java_awt_datatransfer_UnsupportedFlavorException$class_fields;

// Constructors
extern void _jc_java_awt_datatransfer_UnsupportedFlavorException$method$_init$f2f98200a4eb6957(_jc_env *, struct _jc_java_awt_datatransfer_UnsupportedFlavorException$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);

// Virtual methods structure
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods {
};

// Vtable
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods	java_awt_datatransfer_UnsupportedFlavorException;
};

// Vtype
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$refs {
    _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs	java_awt_datatransfer_UnsupportedFlavorException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs	java_awt_datatransfer_UnsupportedFlavorException;
};

// Object instance structure
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$object {
	_jc_java_awt_datatransfer_UnsupportedFlavorException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtype	*vtype;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_UnsupportedFlavorException$vtype _jc_java_awt_datatransfer_UnsupportedFlavorException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_UnsupportedFlavorException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_UnsupportedFlavorException$class_object;

#endif	/* _JC_java_awt_datatransfer_UnsupportedFlavorException_H_ */

==> jc-1.4.6.tar.gz: java/awt/datatransfer/UnsupportedFlavorException.h <==
// public class java.awt.datatransfer.UnsupportedFlavorException

// class file dependencies
// @dep_class 2f25e67d9a1f0e23 java_awt_datatransfer_UnsupportedFlavorException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_datatransfer_UnsupportedFlavorException_H_
#define _JC_java_awt_datatransfer_UnsupportedFlavorException_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs	_jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs	_jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$refs	_jc_java_awt_datatransfer_UnsupportedFlavorException$refs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs	_jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs;
typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$object	_jc_java_awt_datatransfer_UnsupportedFlavorException$object;

typedef struct _jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct	_jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct;
typedef const struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods	_jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods;
typedef const struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtable	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtable;
typedef const struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtype	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtype;

// Class fields structure
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_datatransfer_UnsupportedFlavorException$fields_struct _jc_java_awt_datatransfer_UnsupportedFlavorException$class_fields;

// Constructors
extern void _jc_java_awt_datatransfer_UnsupportedFlavorException$method$_init$f2f98200a4eb6957(_jc_env *, struct _jc_java_awt_datatransfer_UnsupportedFlavorException$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods {
};

// Vtable
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$vmethods	java_awt_datatransfer_UnsupportedFlavorException;
};

// Vtype
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$refs {
    _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_refs	java_awt_datatransfer_UnsupportedFlavorException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_datatransfer_UnsupportedFlavorException$sub_nonrefs	java_awt_datatransfer_UnsupportedFlavorException;
};

// Object instance structure
struct _jc_java_awt_datatransfer_UnsupportedFlavorException$object {
	_jc_java_awt_datatransfer_UnsupportedFlavorException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$vtype	*vtype;
	_jc_java_awt_datatransfer_UnsupportedFlavorException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_UnsupportedFlavorException$vtype _jc_java_awt_datatransfer_UnsupportedFlavorException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_UnsupportedFlavorException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_UnsupportedFlavorException$class_object;

#endif	/* _JC_java_awt_datatransfer_UnsupportedFlavorException_H_ */
